[Scummvm-cvs-logs] scummvm master -> d0f5184edd101e76dd9ad96a2e68c5cc69a662a7

lordhoto lordhoto at gmail.com
Tue May 27 01:00:08 CEST 2014


This automated email contains information about 6 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
9866aba2e4 MADS: Slight formatting fixes.
db3ca8255f MADS: More formatting fixes.
9099b36caa MADS: initialise -> initialize.
b88e2d27a9 MADS: Get rid of some superfluous parentheses.
6a7cc38c89 MADS: synchronise -> synchronize
d0f5184edd MADS: minimise -> minimize


Commit: 9866aba2e43da914a17d17b695456ca25a875469
    https://github.com/scummvm/scummvm/commit/9866aba2e43da914a17d17b695456ca25a875469
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: Slight formatting fixes.

Changed paths:
    engines/mads/dialogs.cpp
    engines/mads/dragonsphere/game_dragonsphere.cpp
    engines/mads/dragonsphere/game_dragonsphere.h
    engines/mads/game.cpp
    engines/mads/game_data.h
    engines/mads/inventory.h
    engines/mads/messages.cpp
    engines/mads/nebular/game_nebular.cpp
    engines/mads/nebular/game_nebular.h
    engines/mads/nebular/globals_nebular.cpp
    engines/mads/nebular/sound_nebular.cpp
    engines/mads/palette.cpp
    engines/mads/phantom/game_phantom.cpp
    engines/mads/phantom/game_phantom.h
    engines/mads/player.cpp
    engines/mads/resources.cpp
    engines/mads/resources.h
    engines/mads/scene.cpp
    engines/mads/scene_data.h
    engines/mads/sprites.cpp



diff --git a/engines/mads/dialogs.cpp b/engines/mads/dialogs.cpp
index b1a0b53..dc8c846 100644
--- a/engines/mads/dialogs.cpp
+++ b/engines/mads/dialogs.cpp
@@ -29,8 +29,9 @@
 
 namespace MADS {
 
-Dialog::Dialog(MADSEngine *vm): _vm(vm), _savedSurface(nullptr),
-		_position(Common::Point(-1, -1)), _width(0), _height(0) {
+Dialog::Dialog(MADSEngine *vm)
+	: _vm(vm), _savedSurface(nullptr), _position(Common::Point(-1, -1)),
+	  _width(0), _height(0) {
 	TEXTDIALOG_CONTENT1 = 0XF8;
 	TEXTDIALOG_CONTENT2 = 0XF9;
 	TEXTDIALOG_EDGE = 0XFA;
@@ -136,8 +137,8 @@ void Dialog::drawContent(const Common::Rect &r, int seed, byte color1, byte colo
 /*------------------------------------------------------------------------*/
 
 TextDialog::TextDialog(MADSEngine *vm, const Common::String &fontName,
-		const Common::Point &pos, int maxChars):
-		Dialog(vm) {
+		const Common::Point &pos, int maxChars)
+	: Dialog(vm) {
 	_vm = vm;
 	_font = _vm->_font->getFont(fontName);
 	_position = pos;
@@ -363,8 +364,8 @@ void TextDialog::show() {
 
 /*------------------------------------------------------------------------*/
 
-MessageDialog::MessageDialog(MADSEngine *vm, int maxChars, ...):
-		TextDialog(vm, FONT_INTERFACE, Common::Point(-1, -1), maxChars) {
+MessageDialog::MessageDialog(MADSEngine *vm, int maxChars, ...)
+	: TextDialog(vm, FONT_INTERFACE, Common::Point(-1, -1), maxChars) {
 	// Add in passed line list
 	va_list va;
 	va_start(va, maxChars);
@@ -389,7 +390,8 @@ Dialogs *Dialogs::init(MADSEngine *vm) {
 	return new Nebular::DialogsNebular(vm);
 }
 
-Dialogs::Dialogs(MADSEngine *vm): _vm(vm) {
+Dialogs::Dialogs(MADSEngine *vm)
+	: _vm(vm) {
 	_pendingDialog = DIALOG_NONE;
 }
 
diff --git a/engines/mads/dragonsphere/game_dragonsphere.cpp b/engines/mads/dragonsphere/game_dragonsphere.cpp
index bee5312..c609712 100644
--- a/engines/mads/dragonsphere/game_dragonsphere.cpp
+++ b/engines/mads/dragonsphere/game_dragonsphere.cpp
@@ -35,7 +35,8 @@ namespace MADS {
 
 namespace Dragonsphere {
 
-GameDragonsphere::GameDragonsphere(MADSEngine *vm): Game(vm) {
+GameDragonsphere::GameDragonsphere(MADSEngine *vm)
+	: Game(vm) {
 	_surface = new MSurface(MADS_SCREEN_WIDTH, MADS_SCENE_HEIGHT);
 	_storyMode = STORYMODE_NAUGHTY;
 }
diff --git a/engines/mads/dragonsphere/game_dragonsphere.h b/engines/mads/dragonsphere/game_dragonsphere.h
index 259c416..b4c4c41 100644
--- a/engines/mads/dragonsphere/game_dragonsphere.h
+++ b/engines/mads/dragonsphere/game_dragonsphere.h
@@ -127,7 +127,7 @@ public:
 
 class Section1Handler: public SectionHandler {
 public:
-	Section1Handler(MADSEngine *vm): SectionHandler(vm) {}
+	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
 	// TODO: Properly implement handler methods
 	virtual void preLoadSection() {}
diff --git a/engines/mads/game.cpp b/engines/mads/game.cpp
index 3f42471..f1744d8 100644
--- a/engines/mads/game.cpp
+++ b/engines/mads/game.cpp
@@ -56,8 +56,9 @@ Game *Game::init(MADSEngine *vm) {
 	return nullptr;
 }
 
-Game::Game(MADSEngine *vm): _vm(vm), _surface(nullptr), _objects(vm),
-		_scene(vm), _screenObjects(vm), _player(vm) {
+Game::Game(MADSEngine *vm)
+	: _vm(vm), _surface(nullptr), _objects(vm), _scene(vm),
+	  _screenObjects(vm), _player(vm) {
 	_sectionNumber = _priorSectionNumber = 0;
 	_loadGameSlot = -1;
 	_lastSave = -1;
diff --git a/engines/mads/game_data.h b/engines/mads/game_data.h
index 6ea59d6..cf2d0bd 100644
--- a/engines/mads/game_data.h
+++ b/engines/mads/game_data.h
@@ -59,7 +59,7 @@ class SectionHandler {
 protected:
 	MADSEngine *_vm;
 public:
-	SectionHandler(MADSEngine *vm): _vm(vm) {}
+	SectionHandler(MADSEngine *vm) : _vm(vm) {}
 	virtual ~SectionHandler() {}
 
 	virtual void preLoadSection() = 0;
diff --git a/engines/mads/inventory.h b/engines/mads/inventory.h
index 7fb123e..a2f35c3 100644
--- a/engines/mads/inventory.h
+++ b/engines/mads/inventory.h
@@ -87,7 +87,7 @@ public:
 	/**
 	 * Constructor
 	 */
-	InventoryObjects(MADSEngine *vm): _vm(vm) {}
+	InventoryObjects(MADSEngine *vm) : _vm(vm) {}
 
 	/**
 	 * Loads the game's object list
diff --git a/engines/mads/messages.cpp b/engines/mads/messages.cpp
index e85a582..f5d1047 100644
--- a/engines/mads/messages.cpp
+++ b/engines/mads/messages.cpp
@@ -42,7 +42,8 @@ void RandomMessages::reset() {
 }
 
 
-KernelMessages::KernelMessages(MADSEngine *vm): _vm(vm) {
+KernelMessages::KernelMessages(MADSEngine *vm)
+	: _vm(vm) {
 	for (int i = 0; i < KERNEL_MESSAGES_SIZE; ++i) {
 		KernelMessage rec;
 		_entries.push_back(rec);
diff --git a/engines/mads/nebular/game_nebular.cpp b/engines/mads/nebular/game_nebular.cpp
index 28daf74..db9ea2c 100644
--- a/engines/mads/nebular/game_nebular.cpp
+++ b/engines/mads/nebular/game_nebular.cpp
@@ -35,7 +35,8 @@ namespace MADS {
 
 namespace Nebular {
 
-GameNebular::GameNebular(MADSEngine *vm): Game(vm) {
+GameNebular::GameNebular(MADSEngine *vm)
+	: Game(vm) {
 	_surface = new MSurface(MADS_SCREEN_WIDTH, MADS_SCENE_HEIGHT);
 	_storyMode = STORYMODE_NAUGHTY;
 	_difficulty = DIFFICULTY_EASY;
diff --git a/engines/mads/nebular/game_nebular.h b/engines/mads/nebular/game_nebular.h
index 56bcf44..ee30492 100644
--- a/engines/mads/nebular/game_nebular.h
+++ b/engines/mads/nebular/game_nebular.h
@@ -129,7 +129,7 @@ public:
 
 class Section1Handler: public SectionHandler {
 public:
-	Section1Handler(MADSEngine *vm): SectionHandler(vm) {}
+	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
 	// TODO: Properly implement handler methods
 	virtual void preLoadSection() {}
diff --git a/engines/mads/nebular/globals_nebular.cpp b/engines/mads/nebular/globals_nebular.cpp
index 7bb89a5..9f8b8a7 100644
--- a/engines/mads/nebular/globals_nebular.cpp
+++ b/engines/mads/nebular/globals_nebular.cpp
@@ -28,7 +28,8 @@ namespace MADS {
 
 namespace Nebular {
 
-NebularGlobals::NebularGlobals(): Globals() {
+NebularGlobals::NebularGlobals()
+	: Globals() {
 	// Initialize lists
 	resize(210);
 	_spriteIndexes.resize(30);
diff --git a/engines/mads/nebular/sound_nebular.cpp b/engines/mads/nebular/sound_nebular.cpp
index 5d1daf1..608a31c 100644
--- a/engines/mads/nebular/sound_nebular.cpp
+++ b/engines/mads/nebular/sound_nebular.cpp
@@ -934,7 +934,8 @@ const ASound1::CommandPtr ASound1::_commandList[42] = {
 	&ASound1::command40, &ASound1::command41
 };
 
-ASound1::ASound1(Audio::Mixer *mixer): ASound(mixer, "asound.001", 0x1520) {
+ASound1::ASound1(Audio::Mixer *mixer)
+	: ASound(mixer, "asound.001", 0x1520) {
 	_cmd23Toggle = false;
 
 	// Load sound samples
diff --git a/engines/mads/palette.cpp b/engines/mads/palette.cpp
index 9f56223..b5a379d 100644
--- a/engines/mads/palette.cpp
+++ b/engines/mads/palette.cpp
@@ -336,7 +336,8 @@ void RGBList::copy(RGBList &src) {
 
 /*------------------------------------------------------------------------*/
 
-Fader::Fader(MADSEngine *vm): _vm(vm) {
+Fader::Fader(MADSEngine *vm)
+	: _vm(vm) {
 	_colorFlags[0] = _colorFlags[1] = _colorFlags[2] = true;
 	_colorFlags[3] = false;
 	_colorValues[0] = _colorValues[1] = 0;
diff --git a/engines/mads/phantom/game_phantom.cpp b/engines/mads/phantom/game_phantom.cpp
index bcaec8e..15ac241 100644
--- a/engines/mads/phantom/game_phantom.cpp
+++ b/engines/mads/phantom/game_phantom.cpp
@@ -35,7 +35,8 @@ namespace MADS {
 
 namespace Phantom {
 
-GamePhantom::GamePhantom(MADSEngine *vm): Game(vm) {
+GamePhantom::GamePhantom(MADSEngine *vm)
+	: Game(vm) {
 	_surface = new MSurface(MADS_SCREEN_WIDTH, MADS_SCENE_HEIGHT);
 	_storyMode = STORYMODE_NAUGHTY;
 }
diff --git a/engines/mads/phantom/game_phantom.h b/engines/mads/phantom/game_phantom.h
index c99e81e..326a1dc 100644
--- a/engines/mads/phantom/game_phantom.h
+++ b/engines/mads/phantom/game_phantom.h
@@ -103,7 +103,7 @@ public:
 
 class Section1Handler: public SectionHandler {
 public:
-	Section1Handler(MADSEngine *vm): SectionHandler(vm) {}
+	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
 	// TODO: Properly implement handler methods
 	virtual void preLoadSection() {}
diff --git a/engines/mads/player.cpp b/engines/mads/player.cpp
index 0777713..aaef9df 100644
--- a/engines/mads/player.cpp
+++ b/engines/mads/player.cpp
@@ -32,7 +32,8 @@ const int Player::_directionListIndexes[32] = {
 	0, 7, 4, 3, 6, 0, 2, 5, 0, 1, 9, 4, 1, 2, 7, 9, 3, 8, 9, 6, 7, 2, 3, 6, 1, 7, 9, 4, 7, 8, 0, 0
 };
 
-Player::Player(MADSEngine *vm): _vm(vm) {
+Player::Player(MADSEngine *vm)
+	: _vm(vm) {
 	_action = nullptr;
 	_facing = FACING_NORTH;
 	_turnToFacing = FACING_NORTH;
diff --git a/engines/mads/resources.cpp b/engines/mads/resources.cpp
index 0bb95de..1fb75e6 100644
--- a/engines/mads/resources.cpp
+++ b/engines/mads/resources.cpp
@@ -44,9 +44,10 @@ private:
 		uint32 _offset;
 		uint32 _size;
 
-		HagEntry(): _offset(0), _size(0) {}
-		HagEntry(Common::String resourceName, uint32 offset, uint32 size):
-			_resourceName(resourceName), _offset(offset), _size(size) {}
+		HagEntry() : _offset(0), _size(0) {}
+		HagEntry(Common::String resourceName, uint32 offset, uint32 size)
+			: _resourceName(resourceName), _offset(offset), _size(size) {
+		}
 	};
 
 	class HagIndex {
diff --git a/engines/mads/resources.h b/engines/mads/resources.h
index 003684e..8d9ab1e 100644
--- a/engines/mads/resources.h
+++ b/engines/mads/resources.h
@@ -58,12 +58,12 @@ public:
 /**
  * Derived file class
  */
-class File: public Common::File {
+class File : public Common::File {
 public:
 	/**
 	 * Constructor
 	 */
-	File(): Common::File() {}
+	File() : Common::File() {}
 
 	/**
 	 * Constructor
diff --git a/engines/mads/scene.cpp b/engines/mads/scene.cpp
index 4af956a..7b54034 100644
--- a/engines/mads/scene.cpp
+++ b/engines/mads/scene.cpp
@@ -30,10 +30,11 @@
 
 namespace MADS {
 
-Scene::Scene(MADSEngine *vm): _vm(vm), _action(_vm), _depthSurface(vm),
-		_dirtyAreas(_vm),  _dynamicHotspots(vm), _hotspots(vm),
-		_kernelMessages(vm), _sequences(vm), _sprites(vm), _spriteSlots(vm),
-		_textDisplay(vm), _userInterface(vm) {
+Scene::Scene(MADSEngine *vm)
+	: _vm(vm), _action(_vm), _depthSurface(vm),
+	  _dirtyAreas(_vm),  _dynamicHotspots(vm), _hotspots(vm),
+	  _kernelMessages(vm), _sequences(vm), _sprites(vm), _spriteSlots(vm),
+	  _textDisplay(vm), _userInterface(vm) {
 	_priorSceneId = 0;
 	_nextSceneId = 0;
 	_currentSceneId = 0;
diff --git a/engines/mads/scene_data.h b/engines/mads/scene_data.h
index 392383a..78b43fb 100644
--- a/engines/mads/scene_data.h
+++ b/engines/mads/scene_data.h
@@ -65,8 +65,9 @@ public:
 	PrepType _prepType;
 
 	VerbInit() {}
-	VerbInit(int id, VerbType verbType, PrepType prepType): _id(id),
-		_verbType(verbType), _prepType(prepType) {}
+	VerbInit(int id, VerbType verbType, PrepType prepType)
+		: _id(id), _verbType(verbType), _prepType(prepType) {
+	}
 };
 
 class SceneLogic {
diff --git a/engines/mads/sprites.cpp b/engines/mads/sprites.cpp
index c98a096..89d610f 100644
--- a/engines/mads/sprites.cpp
+++ b/engines/mads/sprites.cpp
@@ -54,13 +54,14 @@ typedef Common::List<DepthEntry> DepthList;
 
 /*------------------------------------------------------------------------*/
 
-MSprite::MSprite(): MSurface() {
+MSprite::MSprite()
+	: MSurface() {
 }
 
 MSprite::MSprite(Common::SeekableReadStream *source, const Common::Array<RGB6> &palette,
-		const Common::Rect &bounds):
-		MSurface(bounds.width(), bounds.height()),
-		_offset(Common::Point(bounds.left, bounds.top)) {
+		const Common::Rect &bounds)
+	: MSurface(bounds.width(), bounds.height()), 
+	  _offset(Common::Point(bounds.left, bounds.top)) {
 	// Load the sprite data
 	loadSprite(source, palette);
 }


Commit: db3ca8255fd0f237e2b180a94e3124e0caf00e45
    https://github.com/scummvm/scummvm/commit/db3ca8255fd0f237e2b180a94e3124e0caf00e45
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: More formatting fixes.

Add space before : in inheritance.

Changed paths:
    engines/mads/dialogs.h
    engines/mads/dragonsphere/dragonsphere_scenes.h
    engines/mads/dragonsphere/game_dragonsphere.h
    engines/mads/game_data.h
    engines/mads/globals.h
    engines/mads/inventory.h
    engines/mads/messages.h
    engines/mads/nebular/dialogs_nebular.h
    engines/mads/nebular/game_nebular.h
    engines/mads/nebular/globals_nebular.h
    engines/mads/nebular/nebular_scenes1.h
    engines/mads/nebular/nebular_scenes2.h
    engines/mads/nebular/nebular_scenes3.h
    engines/mads/nebular/nebular_scenes4.h
    engines/mads/nebular/nebular_scenes5.h
    engines/mads/nebular/nebular_scenes6.h
    engines/mads/nebular/nebular_scenes7.h
    engines/mads/nebular/nebular_scenes8.h
    engines/mads/nebular/sound_nebular.h
    engines/mads/palette.h
    engines/mads/phantom/game_phantom.h
    engines/mads/phantom/phantom_scenes.h
    engines/mads/sprites.h



diff --git a/engines/mads/dialogs.h b/engines/mads/dialogs.h
index 6de6ea7..aad29f6 100644
--- a/engines/mads/dialogs.h
+++ b/engines/mads/dialogs.h
@@ -96,7 +96,7 @@ public:
 
 #define TEXT_DIALOG_MAX_LINES 20
 
-class TextDialog: protected Dialog {
+class TextDialog : protected Dialog {
 private:
 	/**
 	 * Append text to the currently end line.
@@ -192,7 +192,7 @@ public:
 	virtual void show();
 };
 
-class MessageDialog: public TextDialog {
+class MessageDialog : public TextDialog {
 public:
 	MessageDialog(MADSEngine *vm, int lines, ...);
 
diff --git a/engines/mads/dragonsphere/dragonsphere_scenes.h b/engines/mads/dragonsphere/dragonsphere_scenes.h
index 2d23381..a6c778e 100644
--- a/engines/mads/dragonsphere/dragonsphere_scenes.h
+++ b/engines/mads/dragonsphere/dragonsphere_scenes.h
@@ -677,7 +677,7 @@ public:
 };
 
 // TODO: Temporary, remove once implemented properly
-class DummyScene: public DragonsphereScene {
+class DummyScene : public DragonsphereScene {
 public:
 	DummyScene(MADSEngine *vm) : DragonsphereScene(vm) {
 		warning("Unimplemented scene");
diff --git a/engines/mads/dragonsphere/game_dragonsphere.h b/engines/mads/dragonsphere/game_dragonsphere.h
index b4c4c41..5147f75 100644
--- a/engines/mads/dragonsphere/game_dragonsphere.h
+++ b/engines/mads/dragonsphere/game_dragonsphere.h
@@ -89,7 +89,7 @@ enum InventoryObject {
 };
 
 // HACK: A stub for now, remove from here once it's implemented properly
-class DragonsphereGlobals: public Globals {
+class DragonsphereGlobals : public Globals {
 public:
 	DragonsphereGlobals() {
 		resize(210);	// Rex has 210 globals
@@ -97,7 +97,7 @@ public:
 	virtual ~DragonsphereGlobals() {}
 };
 
-class GameDragonsphere: public Game {
+class GameDragonsphere : public Game {
 	friend class Game;
 protected:
 	GameDragonsphere(MADSEngine *vm);
@@ -125,7 +125,7 @@ public:
 };
 
 
-class Section1Handler: public SectionHandler {
+class Section1Handler : public SectionHandler {
 public:
 	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
diff --git a/engines/mads/game_data.h b/engines/mads/game_data.h
index cf2d0bd..f15cd1a 100644
--- a/engines/mads/game_data.h
+++ b/engines/mads/game_data.h
@@ -32,7 +32,7 @@ namespace MADS {
 class MADSEngine;
 class Game;
 
-class VisitedScenes: public SynchronizedList {
+class VisitedScenes : public SynchronizedList {
 public:
 	/**
 	 * Stores true when a previously visited scene is revisited
diff --git a/engines/mads/globals.h b/engines/mads/globals.h
index 92cd0bb..a6c9b62 100644
--- a/engines/mads/globals.h
+++ b/engines/mads/globals.h
@@ -30,7 +30,7 @@
 
 namespace MADS {
 
-class Globals: public SynchronizedList {
+class Globals : public SynchronizedList {
 public:
 	Globals() {}
 
diff --git a/engines/mads/inventory.h b/engines/mads/inventory.h
index a2f35c3..09ed67a 100644
--- a/engines/mads/inventory.h
+++ b/engines/mads/inventory.h
@@ -77,7 +77,7 @@ public:
 	int getQuality(int qualityId) const;
 };
 
-class InventoryObjects: public Common::Array<InventoryObject> {
+class InventoryObjects : public Common::Array<InventoryObject> {
 private:
 	MADSEngine *_vm;
 
diff --git a/engines/mads/messages.h b/engines/mads/messages.h
index 241f493..1eff14b 100644
--- a/engines/mads/messages.h
+++ b/engines/mads/messages.h
@@ -72,7 +72,7 @@ struct RandomEntry {
 	RandomEntry() { _handle = _quoteId = -1; }
 };
 
-class RandomMessages: public Common::Array<RandomEntry> {
+class RandomMessages : public Common::Array<RandomEntry> {
 public:
 	Common::Rect _bounds;
 	int _randomSpacing;
@@ -147,7 +147,7 @@ public:
 
 #define TEXT_DISPLAY_SIZE 40
 
-class TextDisplayList: public Common::Array<TextDisplay> {
+class TextDisplayList : public Common::Array<TextDisplay> {
 private:
 	MADSEngine *_vm;
 public:
diff --git a/engines/mads/nebular/dialogs_nebular.h b/engines/mads/nebular/dialogs_nebular.h
index 99a93f8..cb1ecfb 100644
--- a/engines/mads/nebular/dialogs_nebular.h
+++ b/engines/mads/nebular/dialogs_nebular.h
@@ -33,7 +33,7 @@ namespace Nebular {
 
 enum CapitalizationMode { kUppercase = 0, kLowercase = 1, kUpperAndLower = 2 };
 
-class DialogsNebular: public Dialogs {
+class DialogsNebular : public Dialogs {
 	friend class Dialogs;
 private:
 	int _dialogWidth;
@@ -62,7 +62,7 @@ struct HOGANUS {
 	Common::String _word;
 };
 
-class CopyProtectionDialog: public TextDialog {
+class CopyProtectionDialog : public TextDialog {
 private:
 	HOGANUS _hogEntry;
 
diff --git a/engines/mads/nebular/game_nebular.h b/engines/mads/nebular/game_nebular.h
index ee30492..6620dea 100644
--- a/engines/mads/nebular/game_nebular.h
+++ b/engines/mads/nebular/game_nebular.h
@@ -96,7 +96,7 @@ enum InventoryObject {
 	OBJ_LECITHIN = 54
 };
 
-class GameNebular: public Game {
+class GameNebular : public Game {
 	friend class Game;
 protected:
 	GameNebular(MADSEngine *vm);
@@ -127,7 +127,7 @@ public:
 };
 
 
-class Section1Handler: public SectionHandler {
+class Section1Handler : public SectionHandler {
 public:
 	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
diff --git a/engines/mads/nebular/globals_nebular.h b/engines/mads/nebular/globals_nebular.h
index 980e6ea..88605a2 100644
--- a/engines/mads/nebular/globals_nebular.h
+++ b/engines/mads/nebular/globals_nebular.h
@@ -280,7 +280,7 @@ enum {
 #define TELEPORTER_WORK_COUNT 6  // Total number that actually work
 
 
-class NebularGlobals: public Globals {
+class NebularGlobals : public Globals {
 public:
 	SynchronizedList _spriteIndexes;
 	SynchronizedList _sequenceIndexes;
diff --git a/engines/mads/nebular/nebular_scenes1.h b/engines/mads/nebular/nebular_scenes1.h
index 96d2bb9..1afa7fc 100644
--- a/engines/mads/nebular/nebular_scenes1.h
+++ b/engines/mads/nebular/nebular_scenes1.h
@@ -53,7 +53,7 @@ public:
 	Scene1xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene101: public Scene1xx {
+class Scene101 : public Scene1xx {
 private:
 	bool _sittingFl;
 	bool _panelOpened;
diff --git a/engines/mads/nebular/nebular_scenes2.h b/engines/mads/nebular/nebular_scenes2.h
index e70444a..c860db9 100644
--- a/engines/mads/nebular/nebular_scenes2.h
+++ b/engines/mads/nebular/nebular_scenes2.h
@@ -49,7 +49,7 @@ public:
 	Scene2xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene201: public Scene2xx {
+class Scene201 : public Scene2xx {
 private:
 	bool _pterodactylFlag;
 
@@ -63,7 +63,7 @@ public:
 	virtual void actions();
 };
 
-class Scene202: public Scene2xx {
+class Scene202 : public Scene2xx {
 private:
 	bool _activeMsgFl, _ladderTopFl, _waitingMeteoFl, _toStationFl, _toTeleportFl;
 	int _ladderHotspotId, _lastRoute, _stationCounter, _meteoFrame;
@@ -88,7 +88,7 @@ public:
 	void setRandomKernelMessage();
 };
 
-class Scene203: public Scene2xx {
+class Scene203 : public Scene2xx {
 private:
 	bool _rhotundaEat2Fl, _rhotundaEatFl;
 
@@ -103,7 +103,7 @@ public:
 	virtual void actions();
 };
 
-class Scene205: public Scene2xx {
+class Scene205 : public Scene2xx {
 private:
 	uint32 _lastFishTime, _chickenTime;
 	bool _beingKicked;
@@ -122,7 +122,7 @@ public:
 	virtual void actions();
 };
 
-class Scene207: public Scene2xx {
+class Scene207 : public Scene2xx {
 private:
 	bool _vultureFl, _spiderFl, _eyeFl;
 	int _spiderHotspotId, _vultureHotspotId;
@@ -142,7 +142,7 @@ public:
 	virtual void actions();
 };
 
-class Scene208: public Scene2xx {
+class Scene208 : public Scene2xx {
 private:
 	bool _rhotundaTurnFl, _boundingFl;
 	int32 _rhotundaTime;
@@ -161,7 +161,7 @@ public:
 	virtual void actions();
 };
 
-class Scene209: public Scene2xx {
+class Scene209 : public Scene2xx {
 private:
 	bool _dodgeFl, _forceDodgeFl, _shouldDodgeFl;
 	bool _pitchFl;
@@ -207,7 +207,7 @@ public:
 	virtual void actions();
 };
 
-class Scene210: public Scene2xx {
+class Scene210 : public Scene2xx {
 private:
 	int _curDialogNode;
 	int _nextHandsPlace;
@@ -246,7 +246,7 @@ public:
 	virtual void actions();
 };
 
-class Scene211: public Scene2xx {
+class Scene211 : public Scene2xx {
 private:
 	bool _ambushFl, _wakeFl;
 	int _monkeyFrame, _scrollY;
@@ -263,7 +263,7 @@ public:
 	virtual void actions();
 };
 
-class Scene212: public Scene2xx {
+class Scene212 : public Scene2xx {
 public:
 	Scene212(MADSEngine *vm) : Scene2xx(vm) {}
 	virtual void setup();
@@ -273,7 +273,7 @@ public:
 	virtual void actions();
 };
 
-class Scene213: public SceneTeleporter {
+class Scene213 : public SceneTeleporter {
 public:
 	Scene213(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -283,7 +283,7 @@ public:
 	virtual void actions();
 };
 
-class Scene214: public Scene2xx {
+class Scene214 : public Scene2xx {
 private:
 	uint32 _devilTime;
 	bool _devilRunningFl;
@@ -298,7 +298,7 @@ public:
 	virtual void actions();
 };
 
-class Scene215: public Scene2xx {
+class Scene215 : public Scene2xx {
 public:
 	Scene215(MADSEngine *vm) : Scene2xx(vm) {}
 
@@ -308,7 +308,7 @@ public:
 	virtual void actions();
 };
 
-class Scene216: public Scene2xx {
+class Scene216 : public Scene2xx {
 public:
 	Scene216(MADSEngine *vm) : Scene2xx(vm) {}
 
diff --git a/engines/mads/nebular/nebular_scenes3.h b/engines/mads/nebular/nebular_scenes3.h
index 30ab333..d44a815 100644
--- a/engines/mads/nebular/nebular_scenes3.h
+++ b/engines/mads/nebular/nebular_scenes3.h
@@ -80,7 +80,7 @@ public:
 	virtual void preActions();
 };
 
-class Scene301: public Scene3xx {
+class Scene301 : public Scene3xx {
 public:
 	Scene301(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -89,7 +89,7 @@ public:
 	virtual void step();
 };
 
-class Scene302: public Scene3xx {
+class Scene302 : public Scene3xx {
 private:
 	int _oldFrame;
 
@@ -102,7 +102,7 @@ public:
 	virtual void step();
 };
 
-class Scene303: public Scene3xx {
+class Scene303 : public Scene3xx {
 public:
 	Scene303(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -111,7 +111,7 @@ public:
 	virtual void step();
 };
 
-class Scene304: public Scene3xx {
+class Scene304 : public Scene3xx {
 private:
 	int _explosionSpriteId;
 
@@ -124,7 +124,7 @@ public:
 	virtual void step();
 };
 
-class Scene307: public Scene3xx {
+class Scene307 : public Scene3xx {
 private:
 	ForceField _forceField;
 
@@ -162,7 +162,7 @@ public:
 	virtual void actions();
 };
 
-class Scene308: public Scene3xx {
+class Scene308 : public Scene3xx {
 private:
 	ForceField _forceField;
 
@@ -175,7 +175,7 @@ public:
 	virtual void step();
 };
 
-class Scene309: public Scene3xx {
+class Scene309 : public Scene3xx {
 private:
 	ForceField _forceField;
 	int _characterSpriteIndexes[3];
@@ -191,7 +191,7 @@ public:
 	virtual void step();
 };
 
-class Scene310: public Scene3xx {
+class Scene310 : public Scene3xx {
 private:
 	ForceField _forceField;
 
@@ -204,7 +204,7 @@ public:
 	virtual void step();
 };
 
-class Scene311: public Scene3xx {
+class Scene311 : public Scene3xx {
 private:
 	bool _checkGuardFl;
 
@@ -218,7 +218,7 @@ public:
 	virtual void actions();
 };
 
-class Scene313: public Scene3xx {
+class Scene313 : public Scene3xx {
 public:
 	Scene313(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -227,7 +227,7 @@ public:
 	virtual void actions();
 };
 
-class Scene316: public Scene3xx {
+class Scene316 : public Scene3xx {
 private:
 	void handleRexInGrate();
 	void handleRoxInGrate();
@@ -242,7 +242,7 @@ public:
 	virtual void actions();
 };
 
-class Scene318: public Scene3xx {
+class Scene318 : public Scene3xx {
 private:
 	uint32 _dropTimer;
 
@@ -278,7 +278,7 @@ public:
 	virtual void actions();
 };
 
-class Scene319: public Scene3xx {
+class Scene319 : public Scene3xx {
 private:
 	Conversation _dialog1, _dialog2, _dialog3;
 
@@ -306,7 +306,7 @@ public:
 	virtual void actions();
 };
 
-class Scene320: public Scene300s {
+class Scene320 : public Scene300s {
 private:
 	void setRightView(int view);
 	void setLeftView(int view);
@@ -331,7 +331,7 @@ public:
 	virtual void actions();
 };
 
-class Scene321: public Scene3xx {
+class Scene321 : public Scene3xx {
 public:
 	Scene321(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -340,7 +340,7 @@ public:
 	virtual void step();
 };
 
-class Scene322: public SceneTeleporter {
+class Scene322 : public SceneTeleporter {
 public:
 	Scene322(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -350,7 +350,7 @@ public:
 	virtual void actions();
 };
 
-class Scene351: public Scene3xx {
+class Scene351 : public Scene3xx {
 public:
 	Scene351(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -360,7 +360,7 @@ public:
 	virtual void actions();
 };
 
-class Scene352: public Scene3xx {
+class Scene352 : public Scene3xx {
 private:
 	bool _vaultOpenFl;
 	bool _mustPutArmDownFl;
@@ -385,7 +385,7 @@ public:
 	virtual void actions();
 };
 
-class Scene353: public Scene3xx {
+class Scene353 : public Scene3xx {
 public:
 	Scene353(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -394,7 +394,7 @@ public:
 	virtual void actions();
 };
 
-class Scene354: public Scene3xx {
+class Scene354 : public Scene3xx {
 public:
 	Scene354(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -404,7 +404,7 @@ public:
 	virtual void actions();
 };
 
-class Scene357: public Scene3xx {
+class Scene357 : public Scene3xx {
 public:
 	Scene357(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -414,7 +414,7 @@ public:
 	virtual void actions();
 };
 
-class Scene358: public Scene3xx {
+class Scene358 : public Scene3xx {
 public:
 	Scene358(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -424,7 +424,7 @@ public:
 	virtual void actions();
 };
 
-class Scene359: public Scene3xx {
+class Scene359 : public Scene3xx {
 private:
 	int _cardHotspotId;
 
@@ -438,7 +438,7 @@ public:
 	virtual void actions();
 };
 
-class Scene360: public Scene3xx {
+class Scene360 : public Scene3xx {
 public:
 	Scene360(MADSEngine *vm) : Scene3xx(vm) {}
 
@@ -448,7 +448,7 @@ public:
 	virtual void actions();
 };
 
-class Scene361: public Scene3xx {
+class Scene361 : public Scene3xx {
 private:
 	void handleRexAction();
 	void handleRoxAction();
@@ -463,7 +463,7 @@ public:
 	virtual void actions();
 };
 
-class Scene366: public Scene300s {
+class Scene366 : public Scene300s {
 public:
 	Scene366(MADSEngine *vm) : Scene300s(vm) {}
 
@@ -472,7 +472,7 @@ public:
 	virtual void actions();
 };
 
-class Scene387: public Scene300s {
+class Scene387 : public Scene300s {
 public:
 	Scene387(MADSEngine *vm) : Scene300s(vm) {}
 
@@ -481,7 +481,7 @@ public:
 	virtual void actions();
 };
 
-class Scene388: public Scene300s {
+class Scene388 : public Scene300s {
 public:
 	Scene388(MADSEngine *vm) : Scene300s(vm) {}
 
@@ -490,7 +490,7 @@ public:
 	virtual void actions();
 };
 
-class Scene389: public Scene300s {
+class Scene389 : public Scene300s {
 private:
 	uint32 _monsterTime;
 
@@ -506,7 +506,7 @@ public:
 	virtual void actions();
 };
 
-class Scene390: public Scene300s {
+class Scene390 : public Scene300s {
 public:
 	Scene390(MADSEngine *vm) : Scene300s(vm) {}
 
@@ -515,7 +515,7 @@ public:
 	virtual void actions();
 };
 
-class Scene391: public Scene300s {
+class Scene391 : public Scene300s {
 public:
 	Scene391(MADSEngine *vm) : Scene300s(vm) {}
 
@@ -524,7 +524,7 @@ public:
 	virtual void actions();
 };
 
-class Scene399: public Scene300s {
+class Scene399 : public Scene300s {
 public:
 	Scene399(MADSEngine *vm) : Scene300s(vm) {}
 
diff --git a/engines/mads/nebular/nebular_scenes4.h b/engines/mads/nebular/nebular_scenes4.h
index 4544e08..fbd5ce8 100644
--- a/engines/mads/nebular/nebular_scenes4.h
+++ b/engines/mads/nebular/nebular_scenes4.h
@@ -50,7 +50,7 @@ public:
 	Scene4xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene401: public Scene4xx {
+class Scene401 : public Scene4xx {
 private:
 	bool _northFl;
 	Common::Point _destPos;
@@ -67,7 +67,7 @@ public:
 	virtual void actions();
 };
 
-class Scene402: public Scene4xx {
+class Scene402 : public Scene4xx {
 private:
 	bool _lightOn;
 	bool _blowingSmoke;
@@ -128,7 +128,7 @@ public:
 	virtual void actions();
 };
 
-class Scene405: public Scene4xx {
+class Scene405 : public Scene4xx {
 public:
 	Scene405(MADSEngine *vm) : Scene4xx(vm) {}
 
@@ -139,7 +139,7 @@ public:
 	virtual void actions();
 };
 
-class Scene406: public Scene4xx {
+class Scene406 : public Scene4xx {
 private:
 	bool _hitStorageDoor;
 
@@ -154,7 +154,7 @@ public:
 	virtual void actions();
 };
 
-class Scene407: public Scene4xx {
+class Scene407 : public Scene4xx {
 private:
 	bool _fromNorth;
 	Common::Point _destPos;
@@ -170,7 +170,7 @@ public:
 	virtual void actions();
 };
 
-class Scene408: public Scene4xx {
+class Scene408 : public Scene4xx {
 public:
 	Scene408(MADSEngine *vm) : Scene4xx(vm) {}
 
@@ -180,7 +180,7 @@ public:
 	virtual void actions();
 };
 
-class Scene409: public SceneTeleporter {
+class Scene409 : public SceneTeleporter {
 public:
 	Scene409(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -190,7 +190,7 @@ public:
 	virtual void actions();
 };
 
-class Scene410: public Scene4xx {
+class Scene410 : public Scene4xx {
 public:
 	Scene410(MADSEngine *vm) : Scene4xx(vm) {}
 
@@ -201,7 +201,7 @@ public:
 	virtual void actions();
 };
 
-class Scene411: public Scene4xx {
+class Scene411 : public Scene4xx {
 private:
 	int _curAnimationFrame;
 	int _newIngredient;
@@ -237,7 +237,7 @@ public:
 	virtual void actions();
 };
 
-class Scene413: public Scene4xx {
+class Scene413 : public Scene4xx {
 private:
 	int _rexDeath;
 	int _canMove;
diff --git a/engines/mads/nebular/nebular_scenes5.h b/engines/mads/nebular/nebular_scenes5.h
index 4022f1c..2face26 100644
--- a/engines/mads/nebular/nebular_scenes5.h
+++ b/engines/mads/nebular/nebular_scenes5.h
@@ -50,7 +50,7 @@ public:
 	Scene5xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene501: public Scene5xx{
+class Scene501 : public Scene5xx{
 private:
 	int _mainSequenceId;
 	int _mainSpriteId;
@@ -70,7 +70,7 @@ public:
 	virtual void actions();
 };
 
-class Scene502: public SceneTeleporter {
+class Scene502 : public SceneTeleporter {
 public:
 	Scene502(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -80,7 +80,7 @@ public:
 	virtual void actions();
 };
 
-class Scene503: public Scene5xx{
+class Scene503 : public Scene5xx{
 private:
 	int _detonatorHotspotId;
 
@@ -93,7 +93,7 @@ public:
 	virtual void actions();
 };
 
-class Scene504: public Scene5xx{
+class Scene504 : public Scene5xx{
 private:
 	int _carAnimationMode;
 	int _carFrame;
@@ -109,7 +109,7 @@ public:
 	virtual void actions();
 };
 
-class Scene505: public Scene5xx{
+class Scene505 : public Scene5xx{
 private:
 	int _frame;
 	int _nextButtonId;
@@ -129,7 +129,7 @@ public:
 	virtual void actions();
 };
 
-class Scene506: public Scene5xx{
+class Scene506 : public Scene5xx{
 private:
 	Common::Point _doorPos;
 	Facing _heroFacing;
@@ -155,7 +155,7 @@ public:
 	virtual void actions();
 };
 
-class Scene507: public Scene5xx{
+class Scene507 : public Scene5xx{
 private:
 	int _penlightHotspotId;
 
@@ -168,7 +168,7 @@ public:
 	virtual void actions();
 };
 
-class Scene508: public Scene5xx{
+class Scene508 : public Scene5xx{
 private:
 	int _chosenObject;
 
@@ -184,7 +184,7 @@ public:
 	virtual void actions();
 };
 
-class Scene511: public Scene5xx{
+class Scene511 : public Scene5xx{
 private:
 	bool _handingLine;
 	bool _lineMoving;
@@ -204,7 +204,7 @@ public:
 	virtual void actions();
 };
 
-class Scene512: public Scene5xx{
+class Scene512 : public Scene5xx{
 private:
   int _fishingRodHotspotId;
   int _keyHotspotId;
@@ -218,7 +218,7 @@ public:
 	virtual void actions();
 };
 
-class Scene513: public Scene5xx{
+class Scene513 : public Scene5xx{
 public:
 	Scene513(MADSEngine *vm) : Scene5xx(vm) {}
 
@@ -228,7 +228,7 @@ public:
 	virtual void actions();
 };
 
-class Scene515: public Scene5xx{
+class Scene515 : public Scene5xx{
 public:
 	Scene515(MADSEngine *vm) : Scene5xx(vm) {}
 
@@ -238,7 +238,7 @@ public:
 	virtual void actions() {};
 };
 
-class Scene551: public Scene5xx{
+class Scene551 : public Scene5xx{
 public:
 	Scene551(MADSEngine *vm) : Scene5xx(vm) {}
 
diff --git a/engines/mads/nebular/nebular_scenes6.h b/engines/mads/nebular/nebular_scenes6.h
index 7446785..c5cac56 100644
--- a/engines/mads/nebular/nebular_scenes6.h
+++ b/engines/mads/nebular/nebular_scenes6.h
@@ -50,7 +50,7 @@ public:
 	Scene6xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene601: public Scene6xx{
+class Scene601 : public Scene6xx{
 public:
 	Scene601(MADSEngine *vm) : Scene6xx(vm) {}
 
@@ -60,7 +60,7 @@ public:
 	virtual void actions();
 };
 
-class Scene602: public Scene6xx{
+class Scene602 : public Scene6xx{
 private:
 	int _lastSpriteIdx;
 	int _lastSequenceIdx;
@@ -78,7 +78,7 @@ public:
 	virtual void actions();
 };
 
-class Scene603: public Scene6xx{
+class Scene603 : public Scene6xx{
 private:
 	int _compactCaseHotspotId;
 	int _noteHotspotId;
@@ -92,7 +92,7 @@ public:
 	virtual void actions();
 };
 
-class Scene604: public Scene6xx{
+class Scene604 : public Scene6xx{
 private:
 	int _timebombHotspotId;
 	int _bombMode;
@@ -115,7 +115,7 @@ public:
 	virtual void actions();
 };
 
-class Scene605: public Scene6xx{
+class Scene605 : public Scene6xx{
 public:
 	Scene605(MADSEngine *vm) : Scene6xx(vm) {}
 
@@ -125,7 +125,7 @@ public:
 	virtual void actions();
 };
 
-class Scene607: public Scene6xx{
+class Scene607 : public Scene6xx{
 private:
 	uint32 _dogTimer;
 	uint32 _lastFrameTime;
@@ -152,7 +152,7 @@ public:
 	virtual void actions();
 };
 
-class Scene608: public Scene6xx{
+class Scene608 : public Scene6xx{
 private:
 	int _carMode;
 	int _carFrame;
@@ -200,7 +200,7 @@ public:
 	virtual void actions();
 };
 
-class Scene609: public Scene6xx{
+class Scene609 : public Scene6xx{
 private:
 	int _videoDoorMode;
 
@@ -217,7 +217,7 @@ public:
 	virtual void actions();
 };
 
-class Scene610: public Scene6xx{
+class Scene610 : public Scene6xx{
 private:
 	int _handsetHotspotId;
 	int _checkVal;
@@ -237,7 +237,7 @@ public:
 	virtual void actions();
 };
 
-class Scene611: public Scene6xx{
+class Scene611 : public Scene6xx{
 private:
 	bool _seenRatFl;
 	bool _eyesRunningFl;
@@ -290,7 +290,7 @@ public:
 	virtual void actions();
 };
 
-class Scene612: public Scene6xx{
+class Scene612 : public Scene6xx{
 private:
 	int _actionMode;
 	int _cycleIndex;
@@ -307,7 +307,7 @@ public:
 	virtual void actions();
 };
 
-class Scene620: public Scene6xx{
+class Scene620 : public Scene6xx{
 public:
 	Scene620(MADSEngine *vm) : Scene6xx(vm) {}
 
diff --git a/engines/mads/nebular/nebular_scenes7.h b/engines/mads/nebular/nebular_scenes7.h
index 454c76e..dfb3c0f 100644
--- a/engines/mads/nebular/nebular_scenes7.h
+++ b/engines/mads/nebular/nebular_scenes7.h
@@ -50,7 +50,7 @@ public:
 	Scene7xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene701: public Scene7xx {
+class Scene701 : public Scene7xx {
 private:
 	int _fishingLineId;
 
@@ -65,7 +65,7 @@ public:
 	virtual void step();
 };
 
-class Scene702: public Scene7xx {
+class Scene702 : public Scene7xx {
 public:
 	Scene702(MADSEngine *vm) : Scene7xx(vm) {}
 
@@ -75,7 +75,7 @@ public:
 	virtual void actions();
 };
 
-class Scene703: public Scene7xx{
+class Scene703 : public Scene7xx{
 private:
 	int _monsterMode;
 	int _boatFrame;
@@ -106,7 +106,7 @@ public:
 	virtual void actions();
 };
 
-class Scene704: public Scene7xx{
+class Scene704 : public Scene7xx{
 private:
 	int _bottleHotspotId;
 	int _boatCurrentFrame;
@@ -131,7 +131,7 @@ public:
 	virtual void actions();
 };
 
-class Scene705: public Scene7xx{
+class Scene705 : public Scene7xx{
 private:
 	Conversation _dialog1;
 
@@ -149,7 +149,7 @@ public:
 	virtual void actions();
 };
 
-class Scene706: public Scene7xx{
+class Scene706 : public Scene7xx{
 private:
 	int _vaseHotspotId;
 	int _vaseMode;
@@ -172,7 +172,7 @@ public:
 	virtual void actions();
 };
 
-class Scene707: public SceneTeleporter {
+class Scene707 : public SceneTeleporter {
 public:
 	Scene707(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -182,7 +182,7 @@ public:
 	virtual void actions();
 };
 
-class Scene710: public Scene7xx {
+class Scene710 : public Scene7xx {
 public:
 	Scene710(MADSEngine *vm) : Scene7xx(vm) {}
 
@@ -192,7 +192,7 @@ public:
 	virtual void actions();
 };
 
-class Scene711: public SceneTeleporter {
+class Scene711 : public SceneTeleporter {
 public:
 	Scene711(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -202,7 +202,7 @@ public:
 	virtual void actions();
 };
 
-class Scene751: public Scene7xx{
+class Scene751 : public Scene7xx{
 private:
 	bool _rexHandingLine;
 
@@ -217,7 +217,7 @@ public:
 	virtual void actions();
 };
 
-class Scene752: public Scene7xx {
+class Scene752 : public Scene7xx {
 private:
 	int _cardId;
 
diff --git a/engines/mads/nebular/nebular_scenes8.h b/engines/mads/nebular/nebular_scenes8.h
index 150951d..39e022e 100644
--- a/engines/mads/nebular/nebular_scenes8.h
+++ b/engines/mads/nebular/nebular_scenes8.h
@@ -52,7 +52,7 @@ public:
 	Scene8xx(MADSEngine *vm) : NebularScene(vm) {}
 };
 
-class Scene801: public Scene8xx{
+class Scene801 : public Scene8xx{
 private:
 	bool _walkThroughDoor;
 
@@ -67,7 +67,7 @@ public:
 	virtual void actions();
 };
 
-class Scene802: public Scene8xx{
+class Scene802 : public Scene8xx{
 public:
 	Scene802(MADSEngine *vm) : Scene8xx(vm) {}
 
@@ -78,7 +78,7 @@ public:
 	virtual void actions();
 };
 
-class Scene803: public Scene8xx{
+class Scene803 : public Scene8xx{
 public:
 	Scene803(MADSEngine *vm) : Scene8xx(vm) {}
 
@@ -89,7 +89,7 @@ public:
 	virtual void actions();
 };
 
-class Scene804: public Scene8xx {
+class Scene804 : public Scene8xx {
 private:
 	bool _messWithThrottle;
 	bool _movingThrottle;
@@ -111,7 +111,7 @@ public:
 	virtual void actions() {};
 };
 
-class Scene805: public Scene8xx{
+class Scene805 : public Scene8xx{
 public:
 	Scene805(MADSEngine *vm) : Scene8xx(vm) {}
 
@@ -122,7 +122,7 @@ public:
 	virtual void actions();
 };
 
-class Scene807: public SceneTeleporter {
+class Scene807 : public SceneTeleporter {
 public:
 	Scene807(MADSEngine *vm) : SceneTeleporter(vm) {}
 
@@ -132,7 +132,7 @@ public:
 	virtual void actions();
 };
 
-class Scene808: public Scene8xx{
+class Scene808 : public Scene8xx{
 private:
 	bool _goingTo803;
 
@@ -145,7 +145,7 @@ public:
 	virtual void actions();
 };
 
-class Scene810: public Scene8xx{
+class Scene810 : public Scene8xx{
 private:
 	bool _moveAllowed;
 
diff --git a/engines/mads/nebular/sound_nebular.h b/engines/mads/nebular/sound_nebular.h
index b5dee5b..2113b10 100644
--- a/engines/mads/nebular/sound_nebular.h
+++ b/engines/mads/nebular/sound_nebular.h
@@ -131,7 +131,7 @@ struct RegisterValue {
 /**
  * Base class for the sound player resource files
  */
-class ASound: public Audio::AudioStream {
+class ASound : public Audio::AudioStream {
 private:
 	struct CachedDataEntry {
 		int _offset;
@@ -365,7 +365,7 @@ public:
 	virtual int getRate() const { return 11025; }
 };
 
-class ASound1: public ASound {
+class ASound1 : public ASound {
 private:
 	typedef int (ASound1::*CommandPtr)();
 	static const CommandPtr _commandList[42];
diff --git a/engines/mads/palette.h b/engines/mads/palette.h
index 0698e21..8b40124 100644
--- a/engines/mads/palette.h
+++ b/engines/mads/palette.h
@@ -246,7 +246,7 @@ public:
 		int tickDelay, int steps);
 };
 
-class Palette: public Fader {
+class Palette : public Fader {
 private:
 	/**
 	 * Initialises the first 16 palette indexes with the equivalent
diff --git a/engines/mads/phantom/game_phantom.h b/engines/mads/phantom/game_phantom.h
index 326a1dc..7a84ee1 100644
--- a/engines/mads/phantom/game_phantom.h
+++ b/engines/mads/phantom/game_phantom.h
@@ -65,7 +65,7 @@ enum InventoryObject {
 };
 
 // HACK: A stub for now, remove from here once it's implemented properly
-class PhantomGlobals: public Globals {
+class PhantomGlobals : public Globals {
 public:
 	PhantomGlobals() {
 		resize(210);	// Rex has 210 globals
@@ -73,7 +73,7 @@ public:
 	virtual ~PhantomGlobals() {}
 };
 
-class GamePhantom: public Game {
+class GamePhantom : public Game {
 	friend class Game;
 protected:
 	GamePhantom(MADSEngine *vm);
@@ -101,7 +101,7 @@ public:
 };
 
 
-class Section1Handler: public SectionHandler {
+class Section1Handler : public SectionHandler {
 public:
 	Section1Handler(MADSEngine *vm) : SectionHandler(vm) {}
 
diff --git a/engines/mads/phantom/phantom_scenes.h b/engines/mads/phantom/phantom_scenes.h
index e585ead..cd295a2 100644
--- a/engines/mads/phantom/phantom_scenes.h
+++ b/engines/mads/phantom/phantom_scenes.h
@@ -503,7 +503,7 @@ public:
 };
 
 // TODO: Temporary, remove once implemented properly
-class DummyScene: public PhantomScene {
+class DummyScene : public PhantomScene {
 public:
 	DummyScene(MADSEngine *vm) : PhantomScene(vm) {
 		warning("Unimplemented scene");
diff --git a/engines/mads/sprites.h b/engines/mads/sprites.h
index f807e73..324122e 100644
--- a/engines/mads/sprites.h
+++ b/engines/mads/sprites.h
@@ -107,7 +107,7 @@ struct SpriteFrameHeader {
 	uint32 reserved8;
 };
 
-class MSprite: public MSurface {
+class MSprite : public MSurface {
 private:
 	void loadSprite(Common::SeekableReadStream *source, const Common::Array<RGB6> &palette);
 public:


Commit: 9099b36caa88d7675a03fb0bd283acf4e1122474
    https://github.com/scummvm/scummvm/commit/9099b36caa88d7675a03fb0bd283acf4e1122474
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: initialise -> initialize.

Changed paths:
    engines/mads/compression.cpp
    engines/mads/compression.h
    engines/mads/font.h
    engines/mads/game.h
    engines/mads/mads.cpp
    engines/mads/mads.h
    engines/mads/msurface.h
    engines/mads/nebular/sound_nebular.cpp
    engines/mads/palette.cpp
    engines/mads/palette.h
    engines/mads/scene.cpp
    engines/mads/scene.h
    engines/mads/screen.h
    engines/mads/sound.h



diff --git a/engines/mads/compression.h b/engines/mads/compression.h
index e6eca42..f7381e4 100644
--- a/engines/mads/compression.h
+++ b/engines/mads/compression.h
@@ -49,7 +49,7 @@ private:
 	int _count;
 	int _dataOffset;
 
-	void initialise(Common::SeekableReadStream *stream);
+	void initialize(Common::SeekableReadStream *stream);
 public:
 	static bool isCompressed(Common::SeekableReadStream *stream);
 	MadsPack(Common::SeekableReadStream *stream);
diff --git a/engines/mads/font.h b/engines/mads/font.h
index 1d73328..47df647 100644
--- a/engines/mads/font.h
+++ b/engines/mads/font.h
@@ -52,7 +52,7 @@ private:
 	static Common::HashMap<Common::String, Font *> *_fonts;
 public:
 	/**
-	 * Initialise the font system
+	 * Initialize the font system
 	 */
 	static void init(MADSEngine *vm);
 
diff --git a/engines/mads/game.h b/engines/mads/game.h
index a55de61..6ec053e 100644
--- a/engines/mads/game.h
+++ b/engines/mads/game.h
@@ -97,7 +97,7 @@ protected:
 	Game(MADSEngine *vm);
 
 	/**
-	 * Initialises the current section number of the game
+	 * Initializes the current section number of the game
 	 */
 	void initSection(int sectionNumber);
 
@@ -110,7 +110,7 @@ protected:
 	virtual ProtectionResult checkCopyProtection() = 0;
 
 	/**
-	 * Initialises global variables for a new game
+	 * Initializes global variables for a new game
 	 */
 	virtual void initializeGlobals() = 0;
 
diff --git a/engines/mads/mads.cpp b/engines/mads/mads.cpp
index bcd8fdb..871d1b5 100644
--- a/engines/mads/mads.cpp
+++ b/engines/mads/mads.cpp
@@ -38,7 +38,7 @@ namespace MADS {
 MADSEngine::MADSEngine(OSystem *syst, const MADSGameDescription *gameDesc) :
 		_gameDescription(gameDesc), Engine(syst), _randomSource("MADS") {
 
-	// Initialise fields
+	// Initialize fields
 	_easyMouse = true;
 	_invObjectsAnimated = true;
 	_textWindowStill = false;
@@ -68,7 +68,7 @@ MADSEngine::~MADSEngine() {
 	delete _sound;
 }
 
-void MADSEngine::initialise() {
+void MADSEngine::initialize() {
 	// Set up debug channels
 	DebugMan.addDebugChannel(kDebugPath, "Path", "Pathfinding debug level");
 	DebugMan.addDebugChannel(kDebugScripts, "scripts", "Game scripts");
@@ -96,7 +96,7 @@ void MADSEngine::initialise() {
 
 Common::Error MADSEngine::run() {
 	initGraphics(MADS_SCREEN_WIDTH, MADS_SCREEN_HEIGHT, false);
-	initialise();
+	initialize();
 
 	// Run the game
 	_game->run();
diff --git a/engines/mads/mads.h b/engines/mads/mads.h
index 3f325fd..9a8f215 100644
--- a/engines/mads/mads.h
+++ b/engines/mads/mads.h
@@ -83,7 +83,7 @@ private:
 	/**
 	 * Handles basic initialisation
 	 */
-	void initialise();
+	void initialize();
 protected:
 	// Engine APIs
 	virtual Common::Error run();
diff --git a/engines/mads/msurface.h b/engines/mads/msurface.h
index e3cf89d..8ad0b1c 100644
--- a/engines/mads/msurface.h
+++ b/engines/mads/msurface.h
@@ -82,7 +82,7 @@ public:
 	virtual ~MSurface();
 
 	/**
-	 * Reinitialises a surface to have a given set of dimensions
+	 * Reinitializes a surface to have a given set of dimensions
 	 */
 	void setSize(int width, int height);
 
diff --git a/engines/mads/nebular/sound_nebular.cpp b/engines/mads/nebular/sound_nebular.cpp
index 608a31c..577ed26 100644
--- a/engines/mads/nebular/sound_nebular.cpp
+++ b/engines/mads/nebular/sound_nebular.cpp
@@ -197,7 +197,7 @@ ASound::ASound(Audio::Mixer *mixer, const Common::String &filename, int dataOffs
 	_mixer->playStream(Audio::Mixer::kPlainSoundType, &_soundHandle, this, -1,
 		Audio::Mixer::kMaxChannelVolume, 0, DisposeAfterUse::NO, true);
 
-	// Initialise the Adlib
+	// Initialize the Adlib
 	adlibInit();
 
 	// Reset the adlib
diff --git a/engines/mads/palette.cpp b/engines/mads/palette.cpp
index b5a379d..755f7bc 100644
--- a/engines/mads/palette.cpp
+++ b/engines/mads/palette.cpp
@@ -504,7 +504,7 @@ void Fader::mapToGreyRamp(byte palette[PALETTE_SIZE], int baseColor, int numColo
 	// Sort the mapping lists
 	insertionSort(numColors, greyList, greyMapping);
 
-	// Initialise state variables
+	// Initialize state variables
 	int greySum = 0;
 	int greyScan = 0;
 	int greyMark = 0;
diff --git a/engines/mads/palette.h b/engines/mads/palette.h
index 8b40124..ff93b2f 100644
--- a/engines/mads/palette.h
+++ b/engines/mads/palette.h
@@ -249,7 +249,7 @@ public:
 class Palette : public Fader {
 private:
 	/**
-	 * Initialises the first 16 palette indexes with the equivalent
+	 * Initializes the first 16 palette indexes with the equivalent
 	 * standard VGA palette
 	 */
 	void initVGAPalette(byte *palette);
@@ -300,7 +300,7 @@ public:
 	void resetGamePalette(int v1, int v2);
 
 	/**
-	 * Initialises the main palette
+	 * Initializes the main palette
 	 */
 	void initPalette();
 
diff --git a/engines/mads/scene.cpp b/engines/mads/scene.cpp
index 7b54034..d2d4bd8 100644
--- a/engines/mads/scene.cpp
+++ b/engines/mads/scene.cpp
@@ -154,7 +154,7 @@ void Scene::loadScene(int sceneId, const Common::String &prefix, bool palFlag) {
 	_sceneInfo->load(_currentSceneId, _variant, Common::String(), flags,
 		_depthSurface, _backgroundSurface);
 
-	// Initialise palette animation for the scene
+	// Initialize palette animation for the scene
 	initPaletteAnimation(_sceneInfo->_paletteCycles, false);
 
 	// Copy over nodes
diff --git a/engines/mads/scene.h b/engines/mads/scene.h
index 7a01d73..c53c4d6 100644
--- a/engines/mads/scene.h
+++ b/engines/mads/scene.h
@@ -53,7 +53,7 @@ private:
 	void loadVocabStrings();
 
 	/*
-	 * Initialises the data for palette animation within the scene
+	 * Initializes the data for palette animation within the scene
 	 */
 	void initPaletteAnimation(Common::Array<PaletteCycle> &palCycles, bool animFlag);
 
diff --git a/engines/mads/screen.h b/engines/mads/screen.h
index b81fddd..a3653d6 100644
--- a/engines/mads/screen.h
+++ b/engines/mads/screen.h
@@ -209,7 +209,7 @@ public:
 	ScreenSurface();
 
 	/**
-	 * Initialise the surface
+	 * Initialize the surface
 	 */
 	void init();
 
diff --git a/engines/mads/sound.h b/engines/mads/sound.h
index 0fd9ac1..9a251f9 100644
--- a/engines/mads/sound.h
+++ b/engines/mads/sound.h
@@ -47,7 +47,7 @@ public:
 	~SoundManager();
 
 	/**
-	 * Initialises the sound driver for a given game section
+	 * Initializes the sound driver for a given game section
 	 */
 	void init(int sectionNumber);
 


Commit: b88e2d27a90d8493395684f2b72cba4d2f02c54d
    https://github.com/scummvm/scummvm/commit/b88e2d27a90d8493395684f2b72cba4d2f02c54d
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: Get rid of some superfluous parentheses.

Changed paths:
    engines/mads/nebular/nebular_scenes4.cpp
    engines/mads/nebular/nebular_scenes8.cpp



diff --git a/engines/mads/nebular/nebular_scenes4.cpp b/engines/mads/nebular/nebular_scenes4.cpp
index 017319b..d369947 100644
--- a/engines/mads/nebular/nebular_scenes4.cpp
+++ b/engines/mads/nebular/nebular_scenes4.cpp
@@ -2930,7 +2930,7 @@ void Scene408::actions() {
 		_vm->_sound->command(58);
 	} else if (_action.isAction(VERB_TAKE, NOUN_TARGET_MODULE) && (_game._objects.isInRoom(OBJ_TARGET_MODULE) || _game._trigger)) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_vm->_sound->command(57);
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
@@ -3178,7 +3178,7 @@ void Scene410::actions() {
 		_scene->_nextSceneId = 406;
 	else if (_action.isAction(VERB_TAKE, NOUN_CHARGE_CASES) && (_game._objects.isInRoom(OBJ_CHARGE_CASES) || _game._trigger)) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_vm->_sound->command(57);
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
@@ -3447,18 +3447,18 @@ int Scene411::computeQuoteAndQuantity() {
 
 void Scene411::handleKettleAction() {
 	switch (_globals[kNextIngredient]) {
-	case (1):
+	case 1:
 		_globals._sequenceIndexes[4] = _scene->_sequences.addSpriteCycle(_globals._spriteIndexes[4],
 			false, 15, 0, 0, 0);
 		break;
 
-	case (2):
+	case 2:
 		_scene->_sequences.remove(_globals._sequenceIndexes[4]);
 		_globals._sequenceIndexes[4] = _scene->_sequences.addSpriteCycle(_globals._spriteIndexes[4],
 			false, 6, 0, 0, 0);
 		break;
 
-	case (3):
+	case 3:
 		_makeMushroomCloud = true;
 		break;
 
@@ -3511,19 +3511,19 @@ void Scene411::handleDialog() {
 
 void Scene411::giveToRex(int object) {
 	switch (object) {
-	case (0):
+	case 0:
 		_game._objects.addToInventory(OBJ_ALIEN_LIQUOR);
 		break;
 
-	case (1):
+	case 1:
 		_game._objects.addToInventory(OBJ_LECITHIN);
 		break;
 
-	case (2):
+	case 2:
 		_game._objects.addToInventory(OBJ_PETROX);
 		break;
 
-	case (3):
+	case 3:
 		_game._objects.addToInventory(OBJ_FORMALDEHYDE);
 		break;
 
@@ -3606,7 +3606,7 @@ void Scene411::enter() {
 			_globals._sequenceIndexes[4] = _scene->_sequences.addSpriteCycle(_globals._spriteIndexes[4], false, 6, 0, 0, 0);
 			break;
 
-		case (4):
+		case 4:
 			_vm->_sound->command(53);
 			_vm->_sound->command(54);
 			_vm->_sound->command(55);
@@ -3713,10 +3713,10 @@ void Scene411::step() {
 				}
 				break;
 
-			case (22):
-			case (41):
-			case (59):
-			case (115):
+			case 22:
+			case 41:
+			case 59:
+			case 115:
 				if (_makeMushroomCloud) {
 					_globals._sequenceIndexes[9] = _scene->_sequences.addSpriteCycle(_globals._spriteIndexes[9], false, 5, 1, 0, 0);
 					_makeMushroomCloud = false;
@@ -3838,7 +3838,7 @@ void Scene411::actions() {
 
 	if (_action.isAction(VERB_TAKE, NOUN_PETROX) && (_game._objects.isInRoom(OBJ_PETROX) || _game._trigger)) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_vm->_sound->command(57);
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
@@ -3875,7 +3875,7 @@ void Scene411::actions() {
 
 	if (_action.isAction(VERB_TAKE, NOUN_LECITHIN) && (_game._objects.isInRoom(OBJ_LECITHIN) || _game._trigger)) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_vm->_sound->command(57);
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
@@ -3937,19 +3937,19 @@ void Scene411::actions() {
 		if (_action.isObject(NOUN_PETROX) || _action.isObject(NOUN_FORMALDEHYDE) || _action.isObject(NOUN_LECITHIN) || _action.isObject(NOUN_ALIEN_LIQUOR)) {
 			_newIngredient = _game._objects.getIdFromDesc(_action._activeAction._objectNameId);
 			switch (_newIngredient) {
-			case (OBJ_ALIEN_LIQUOR):
+			case OBJ_ALIEN_LIQUOR:
 				_dialog1.start();
 				break;
 
-			case (OBJ_FORMALDEHYDE):
+			case OBJ_FORMALDEHYDE:
 				_dialog3.start();
 				break;
 
-			case (OBJ_PETROX):
+			case OBJ_PETROX:
 				_dialog4.start();
 				break;
 
-			case (OBJ_LECITHIN):
+			case OBJ_LECITHIN:
 				_dialog2.start();
 				break;
 
diff --git a/engines/mads/nebular/nebular_scenes8.cpp b/engines/mads/nebular/nebular_scenes8.cpp
index db9024b..6650283 100644
--- a/engines/mads/nebular/nebular_scenes8.cpp
+++ b/engines/mads/nebular/nebular_scenes8.cpp
@@ -416,7 +416,7 @@ void Scene802::preActions() {
 void Scene802::actions() {
 	if (_action.isAction(VERB_TAKE, NOUN_SHIELD_MODULATOR) && !_game._objects.isInInventory(OBJ_SHIELD_MODULATOR)) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
 			_globals._sequenceIndexes[2] = _scene->_sequences.startReverseCycle(_globals._spriteIndexes[2], true, 7, 2, 0, 0);
@@ -448,7 +448,7 @@ void Scene802::actions() {
 		}
 	} else if ((_action.isAction(VERB_TAKE, NOUN_REMOTE)) && (!_game._objects.isInInventory(OBJ_REMOTE))) {
 		switch (_game._trigger) {
-		case (0):
+		case 0:
 			_game._player._stepEnabled = false;
 			_game._player._visible = false;
 			_globals._sequenceIndexes[5] = _scene->_sequences.startReverseCycle(_globals._spriteIndexes[5], true, 7, 2, 0, 0);


Commit: 6a7cc38c89305cecdcb6414fe438615beb931eca
    https://github.com/scummvm/scummvm/commit/6a7cc38c89305cecdcb6414fe438615beb931eca
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: synchronise -> synchronize

Changed paths:
    engines/mads/game.h
    engines/mads/scene.h



diff --git a/engines/mads/game.h b/engines/mads/game.h
index 6ec053e..3a84a72 100644
--- a/engines/mads/game.h
+++ b/engines/mads/game.h
@@ -184,9 +184,9 @@ public:
 	virtual void step() = 0;
 
 	/**
-	 * Synchronise the game data
+	 * Synchronize the game data
 	 * @param s			Serializer
-	 * @param phase1	If true, it's synchronising the basic scene information
+	 * @param phase1	If true, it's synchronizing the basic scene information
 	 */
 	virtual void synchronize(Common::Serializer &s, bool phase1);
 
diff --git a/engines/mads/scene.h b/engines/mads/scene.h
index c53c4d6..407d70d 100644
--- a/engines/mads/scene.h
+++ b/engines/mads/scene.h
@@ -241,7 +241,7 @@ public:
 	void freeAnimation();
 
 	/**
-	* Synchronise the game
+	* Synchronize the game
 	*/
 	void synchronize(Common::Serializer &s);
 };


Commit: d0f5184edd101e76dd9ad96a2e68c5cc69a662a7
    https://github.com/scummvm/scummvm/commit/d0f5184edd101e76dd9ad96a2e68c5cc69a662a7
Author: Johannes Schickel (lordhoto at scummvm.org)
Date: 2014-05-27T00:58:25+02:00

Commit Message:
MADS: minimise -> minimize

Changed paths:
    engines/mads/sprites.cpp



diff --git a/engines/mads/sprites.cpp b/engines/mads/sprites.cpp
index 89d610f..0dc83d1 100644
--- a/engines/mads/sprites.cpp
+++ b/engines/mads/sprites.cpp
@@ -324,7 +324,7 @@ void SpriteSlots::drawSprites(MSurface *s) {
 		}
 
 		if ((slot._scale < 100) && (slot._scale != -1)) {
-			// Minimalised drawing
+			// Minimalized drawing
 			s->copyFrom(spr, slot._position, slot._depth, &scene._depthSurface,
 				slot._scale, sprite->getTransparencyIndex());
 		} else {






More information about the Scummvm-git-logs mailing list
diff --git a/engines/mads/compression.cpp b/engines/mads/compression.cpp
index 2284f17..5f78357 100644
--- a/engines/mads/compression.cpp
+++ b/engines/mads/compression.cpp
@@ -42,16 +42,16 @@ bool MadsPack::isCompressed(Common::SeekableReadStream *stream) {
 }
 
 MadsPack::MadsPack(Common::SeekableReadStream *stream) {
-	initialise(stream);
+	initialize(stream);
 }
 
 MadsPack::MadsPack(const Common::String &resourceName, MADSEngine *vm) {
 	File file(resourceName);
-	initialise(&file);
+	initialize(&file);
 	file.close();
 }
 
-void MadsPack::initialise(Common::SeekableReadStream *stream) {
+void MadsPack::initialize(Common::SeekableReadStream *stream) {
 	if (!MadsPack::isCompressed(stream))
 		error("Attempted to decompress a resource that was not MadsPacked");
 
@@ -124,7 +124,7 @@ void FabDecompressor::decompress(const byte *srcData, int srcSize, byte *destDat
 	copyOfs = 0xFFFF0000;
 	destP = destData;
 
 	// Initialise data fields
 	_srcData = srcData;
 	_srcP = _srcData + 6;
 	_srcSize = srcSize;
@@ -124,7 +124,7 @@ void FabDecompressor::decompress(const byte *srcData, int srcSize, byte *destDat
 	destP = destData;
 
-	// Initialise data fields
+	// Initialize data fields
 	_srcData = srcData;
 	_srcP = _srcData + 6;